@@ -17,18 +17,6 @@ impl std::fmt::Debug for Position {
     }
 }
 
-impl std::fmt::Display for Position {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        write!(f, "{self:?}")
-    }
-}
-
-impl std::hash::Hash for Position {
-    fn hash<H: Hasher>(&self, state: &mut H) {
-        self.index.hash(state);
-    }
-}
-
 impl std::cmp::Ord for Position {
     fn cmp(&self, other: &Position) -> std::cmp::Ordering {
         self.index.cmp(&other.index)
@@ -46,3 +34,40 @@ impl std::cmp::PartialEq for Position {
         self.index == other.index
     }
 }
+
+impl std::default::Default for Position {
+    fn default() -> Position {
+        Position::new()
+    }
+}
+
+impl std::fmt::Display for Position {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "{self:?}")
+    }
+}
+
+impl std::hash::Hash for Position {
+    fn hash<H: Hasher>(&self, state: &mut H) {
+        self.index.hash(state);
+    }
+}
+
+impl Position {
+    pub(crate) fn consume(&mut self, input: &str) {
+        for char in input.chars() {
+            self.index += input.len();
+
+            if char == '\n' {
+                self.line += 1;
+                self.column = 1;
+            } else {
+                self.column += 1;
+            }
+        }
+    }
+
+    pub fn new() -> Position {
+        Position { column: 1, index: 0, line: 1 }
+    }
+}
